#!/usr/bin/env node
"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const TemplateGenerator_1 = require("./TemplateGenerator");
const PackageJsonGenerator_1 = require("./PackageJsonGenerator");
const FolderStructureGenerator_1 = require("./FolderStructureGenerator");
const OpenApiGenerator_1 = require("./OpenApiGenerator");
const WebpackGenerator_1 = require("./WebpackGenerator");
const TsConfigGenerator_1 = require("./TsConfigGenerator");
const TestFunctionGenerator_1 = require("./TestFunctionGenerator");
const TestSuiteGenerator_1 = require("./TestSuiteGenerator");
const chalk_1 = __importDefault(require("chalk"));
const clear_1 = __importDefault(require("clear"));
const figlet_1 = __importDefault(require("figlet"));
const commander_1 = require("commander");
const inquirer_1 = __importDefault(require("inquirer"));
clear_1.default();
const program = new commander_1.Command();
program.version('0.0.1');
console.log(chalk_1.default.green(figlet_1.default.textSync('sam-bootstrap', { horizontalLayout: 'full' })));
const start = () => __awaiter(void 0, void 0, void 0, function* () {
    const projectNameResponse = yield inquirer_1.default.prompt([
        {
            type: 'input',
            message: 'Project name?',
            name: 'name',
        },
    ]);
    const authorNameResponse = yield inquirer_1.default.prompt([
        {
            type: 'input',
            message: 'Author name?',
            name: 'name',
        },
    ]);
    const projectTypeResponse = yield inquirer_1.default.prompt([
        {
            type: 'list',
            message: 'frontend or backend?',
            name: 'projectType',
            choices: ['frontend (WIP)', 'backend'],
            validate: (answer) => {
                if (!answer.length)
                    return 'You must select an option';
                return true;
            },
        },
    ]);
    let applicationDescription;
    if (projectTypeResponse.projectType === 'frontend (WIP)') {
        console.log('Frontend template is still a work in progres...');
        return;
    }
    if (projectTypeResponse.projectType === 'backend') {
        applicationDescription = yield inquirer_1.default.prompt([
            {
                type: 'input',
                message: 'Description for the application?',
                name: 'description',
                validate: (answer) => {
                    if (!answer.length)
                        return 'You enter a description';
                    return true;
                },
            },
        ]);
        TemplateGenerator_1.generateBackendTemplate({
            description: applicationDescription.description,
            endpointType: 'REGIONAL',
        });
    }
    const testingSuiteConfigurationResponse = yield inquirer_1.default.prompt([
        {
            type: 'list',
            message: 'What testing suite would you like the API to use?',
            name: 'suite',
            choices: ['Mocha (default)', 'Jest'],
            validate: (answer) => {
                if (!answer.length)
                    return 'You must select an option';
                return true;
            },
        },
    ]);
    FolderStructureGenerator_1.generateFolderStructure({});
    TestSuiteGenerator_1.generateTestingSuiteFiles({ testSuite: testingSuiteConfigurationResponse.suite });
    PackageJsonGenerator_1.generatePackageJson({
        projectName: projectNameResponse.name,
        author: authorNameResponse.name,
        description: applicationDescription.description,
        testSuite: testingSuiteConfigurationResponse.suite,
    });
    OpenApiGenerator_1.generateOpenApiDefinition({
        projectName: projectNameResponse.name,
        projectDescription: applicationDescription.description,
    });
    WebpackGenerator_1.generateWebpackFiles();
    TsConfigGenerator_1.generateTsConfig({});
    TestFunctionGenerator_1.generateTestLambdaFunction({});
});
start();
